<?php
/**
 * Plugin Name:       Fay Chat
 * Plugin URI:        https://wordpress.org/plugins/fay-chat/
 * Description:       Fay Chat allows you to integrate your WhatsApp directly into your website. You also can add multiple employees with WhatsApp numbers. Your website’s visitors and customers will appreciate the opportunity.
 * Version:           1.10.7
 * Requires at least: 5.2
 * Requires PHP:      7.2
 * Author:            ByteLabX
 * Author URI:        https://bytelabx.com/
 * License:           GPL v2 or later
 * License URI:       https://www.gnu.org/licenses/gpl-2.0.html
 * Text Domain:       fay-chat
 */


if ( ! defined( 'ABSPATH' ) ) {
    die( 'You cannot jump here!!' );
}


//Add matabox of "Designation of Agent" & "WhatsApp Number"
class Fay_Chat {
    private $config = '{"title":"Additional options","description":"","prefix":"additional_options_","domain":"fay-chat","class_name":"Fay_Chat","post-type":["faychat"],"context":"normal","priority":"default","cpt":"faychat","fields":[{"type":"text","label":"Designation of Agent","id":"additional_options_designation"},{"type":"tel","label":"Whatsapp Number","id":"additional_options_phone"}]}';
    public function __construct() {
        $this->config = json_decode( $this->config, true );
        $this->process_cpts();
        add_action( 'add_meta_boxes', [ $this, 'add_meta_boxes' ] );
        add_action( 'admin_head', [ $this, 'admin_head' ] );
        add_action( 'save_post', [ $this, 'save_post' ] );
    }
    public function process_cpts() {
        if ( !empty( $this->config['cpt'] ) ) {
            if ( empty( $this->config['post-type'] ) ) {
                $this->config['post-type'] = [];
            }
            $parts = explode( ',', $this->config['cpt'] );
            $parts = array_map( 'trim', $parts );
            $this->config['post-type'] = array_merge( $this->config['post-type'], $parts );
        }
    }
    public function add_meta_boxes() {
        foreach ( $this->config['post-type'] as $screen ) {
            add_meta_box(
                sanitize_title( $this->config['title'] ),
                $this->config['title'],
                [ $this, 'add_meta_box_callback' ],
                $screen,
                $this->config['context'],
                $this->config['priority']
            );
        }
    }
    public function admin_head() {
        global $typenow;
        if ( in_array( $typenow, $this->config['post-type'] ) ) {
            ?><?php
        }
    }
    public function save_post( $post_id ) {
        foreach ( $this->config['fields'] as $field ) {
            switch ( $field['type'] ) {
                default:
                    if ( isset( $_POST[ $field['id'] ] ) ) {
                        $sanitized = sanitize_text_field( $_POST[ $field['id'] ] );
                        update_post_meta( $post_id, $field['id'], $sanitized );
                    }
            }
        }
    }
    public function add_meta_box_callback() {
        echo '<div class="rwp-description">' . $this->config['description'] . '</div>';
        $this->fields_table();
    }
    private function fields_table() {
        ?><table class="form-table" role="presentation">
        <tbody><?php
        foreach ( $this->config['fields'] as $field ) {
            ?><tr>
            <th scope="row"><?php $this->label( $field ); ?></th>
            <td><?php $this->field( $field ); ?></td>
            </tr><?php
        }
        ?></tbody>
        </table><?php
    }
    private function label( $field ) {
        switch ( $field['type'] ) {
            default:
                printf(
                    '<label class="" for="%s">%s</label>',
                    $field['id'], $field['label']
                );
        }
    }
    private function field( $field ) {
        switch ( $field['type'] ) {
            default:
                $this->input( $field );
        }
    }
    private function input( $field ) {
        printf(
            '<input class="regular-text %s" id="%s" name="%s" %s type="%s" value="%s" required>',
            isset( $field['class'] ) ? $field['class'] : '',
            $field['id'], $field['id'],
            isset( $field['pattern'] ) ? "pattern='{$field['pattern']}'" : '',
            $field['type'],
            $this->value( $field )
        );
        if ($field['id'] == "additional_options_phone"){
            ?>
            <br>
            <br>
            <strong>Notice: Please enter phone number with country code.<br>
                (Country Code: 1 for USA, 44 for UK <a href="https://countrycode.org/" target="_blank">For More)</a>
            </strong>
            <h2 style="color: red; padding-left: 0;">Enter whatsApp Number with country code without plus (+)</h2>
            <p>For free support send me an email. => fayjur500@gmail.com</p>
            <?php
        }
    }
    private function value( $field ) {
        global $post;
        if ( metadata_exists( 'post', $post->ID, $field['id'] ) ) {
            $value = get_post_meta( $post->ID, $field['id'], true );
        } else if ( isset( $field['default'] ) ) {
            $value = $field['default'];
        } else {
            return '';
        }
        return str_replace( '\u0027', "'", $value );
    }
}
new Fay_Chat;


//plugin uninstallation & remove all the post
function fay_chat_uninstall() {
    $fay_chat_posts= get_posts( array('post_type'=>'faychat','post_status'=> array( 'any','trash' ) ) );
    foreach ($fay_chat_posts as $each_fay_chatpost) {
        wp_delete_post( $each_fay_chatpost->ID, true );
    }
    delete_metadata( 'post', 0, 'additional_options_designation', false, true );
    delete_metadata( 'post', 0, 'additional_options_phone', false, true );
}
register_uninstall_hook( __FILE__, 'fay_chat_uninstall' );


//CSS and JS file link
function fay_chat_assets(){
    wp_enqueue_style('fay-chat-css', plugin_dir_url(__FILE__) . "assets/css/faychat-chat.css", null, 1.0);
    wp_enqueue_style('style-main', plugin_dir_url(__FILE__) . "assets/css/style.css", null, 1.0);
    wp_enqueue_script('fay-chat-script-main', plugin_dir_url(__FILE__) . "assets/js/fay-chat.js", array('jquery'), 1.0, false);
}
add_action('wp_enqueue_scripts', 'fay_chat_assets');


//Add html to body
function fay_chat_body(){
    _e('<div id="fay_chat_main"></div>','fay-chat');
}
add_action('wp_body_open', 'fay_chat_body');


//Javascript in the footer
function fay_chat_footer()
{
    // WP_Query arguments
    $fay_chat_args = array(
        'post_type'              => array( 'faychat' ),
        'post_status'            => array( 'publish' ),
    );
    // The Query
    $fay_chat_query = new WP_Query( $fay_chat_args );
    $fay_chat_headerMessage_php = esc_html('Feel free to ask any questions in WhatsApp.');
    $fay_chat_chatBoxMessage_php = esc_html('Team replies in a minute.');

    //initial the js object for Fay Chat
    ?>
    <script>
        var fay_chat_selector = '<?php _e('#fay_chat_main','fay-chat') ?>';
        var fay_chat_headerMessage = '<?php _e($fay_chat_headerMessage_php,'fay-chat') ?>';
        var fay_chat_chatBoxMessage = '<?php _e($fay_chat_chatBoxMessage_php,'fay-chat') ?>';
        var fay_chat_color = '<?php _e("#F57C00",'fay-chat') ?>';
        var agent_info =  {
            selector: fay_chat_selector,
            users: [],
            headerMessage: fay_chat_headerMessage,
            chatBoxMessage: fay_chat_chatBoxMessage,
            color: fay_chat_color,
        };
    </script>
    <?php
    // The Loop
    if ( $fay_chat_query->have_posts() ) {
        while ( $fay_chat_query->have_posts() ) {
            $fay_chat_query->the_post();
            if(get_the_post_thumbnail_url(get_the_ID(), 'full') != ''){
                $fay_chat_agent_image_php = esc_url(get_the_post_thumbnail_url(get_the_ID(), 'full'));
            }
            else{
                $fay_chat_agent_image_php = esc_url(plugin_dir_url(__FILE__).'assets/img/user.png');
            }
            $fay_chat_agent_title_php = esc_html(get_the_title());
            $fay_chat_agent_description_php = esc_html(get_post_meta(get_the_ID(), 'additional_options_designation', true));
            $fay_chat_agent_phone_php = esc_html(get_post_meta(get_the_ID(), 'additional_options_phone', true));
            ?>
            <script>
                var fay_chat_agent_name = '<?php _e( $fay_chat_agent_title_php, 'fay-chat' ); ?>';
                var fay_chat_agent_phone = '<?php _e( $fay_chat_agent_phone_php, 'fay-chat' ); ?>';
                var fay_chat_agent_designation = '<?php _e( $fay_chat_agent_description_php, 'fay-chat' ) ?>';
                var fay_chat_agent_image = '<?php _e( $fay_chat_agent_image_php, 'fay-chat' ) ?>';
                var fay_chat_user_info={
                    name: fay_chat_agent_name,
                    phone: fay_chat_agent_phone,
                    designation: fay_chat_agent_designation,
                    image: fay_chat_agent_image
                };
                agent_info.users.push(fay_chat_user_info);
            </script>
            <?php
        }
        ?>
        <!--Call Fay Chat js for showing plugin only if have post-->
        <script type="text/javascript">
            fayChat.multipleUser(agent_info);
        </script>
        <?php
    }
    else {
        $fay_chat_deafult_name_php = esc_html('The agent is not available right now.');
        $fay_chat_deafult_image_php = esc_url(plugin_dir_url(  __FILE__  ).'assets/img/user.png');
        
        ?>
        <!--Call Fay Chat js for showing plugin only if doesn't have post-->
        <script type="text/javascript">
            var fay_chat_name= '<?php _e($fay_chat_deafult_name_php,'fay-chat'); ?>';
            var fay_chat_image= '<?php _e($fay_chat_deafult_image_php,'fay-chat'); ?>';
            var fay_chat_active= '<?php _e(false,'fay-chat'); ?>';
            var fay_chat_not_available= '<?php _e(true,'fay-chat'); ?>';
              var info = {
                    selector: fay_chat_selector,
                    users: [
                        {
                            name: fay_chat_name,
                            image : fay_chat_image,
                            active: fay_chat_active,
                        },
                    ],
                    headerMessage: fay_chat_headerMessage,
                    chatBoxMessage: fay_chat_chatBoxMessage,
                    color: fay_chat_color,
                    not_available: fay_chat_not_available,
                };
                fayChat.multipleUser(info);
        </script>
        <?php
    }
    // Restore original Post Data
    wp_reset_postdata();

}
add_action('wp_footer', 'fay_chat_footer');


//Update place holder of title input
add_filter('enter_title_here', 'fay_chatagent_title_place_holder' , 20 , 2 );
function fay_chatagent_title_place_holder($fay_chatitem_title , $fay_chatpost){
    if( $fay_chatpost->post_type == 'faychat' ){
        $fay_chattitle = __( 'Enter Agent Name.....', 'fay-chat' );
        return $fay_chattitle;
    }
    return $fay_chatitem_title;
}


//Add user
if (!function_exists('fay_chatcustom_post_type')) {
// Register Custom Post Type
    function fay_chatcustom_post_type()
    {
        $labels = array(
            'name' => _x('Fay Chat Agent', 'Post Type General Name', 'fay-chat'),
            'singular_name' => _x('Fay Chat Type', 'Post Type Singular Name', 'fay-chat'),
            'menu_name' => __('Fay Chat', 'fay-chat'),
            'name_admin_bar' => __('Post Type', 'fay-chat'),
            'archives' => __('Agent Archives', 'fay-chat'),
            'attributes' => __('Agent Attributes', 'fay-chat'),
            'parent_item_colon' => __('Parent Agent:', 'fay-chat'),
            'all_items' => __('All Agents', 'fay-chat'),
            'add_new_item' => __('Add New Agent', 'fay-chat'),
            'add_new' => __('Add Agent', 'fay-chat'),
            'new_item' => __('New Agent', 'fay-chat'),
            'edit_item' => __('Edit Agent', 'fay-chat'),
            'update_item' => __('Update Agent', 'fay-chat'),
            'view_item' => __('View Agent', 'fay-chat'),
            'view_items' => __('View Agents', 'fay-chat'),
            'search_items' => __('Search Agent', 'fay-chat'),
            'not_found' => __('Not found', 'fay-chat'),
            'not_found_in_trash' => __('Not found in Trash', 'fay-chat'),
            'featured_image' => __('Agent image', 'fay-chat'),
            'set_featured_image' => __('Set agent image', 'fay-chat'),
            'remove_featured_image' => __('Remove featured image', 'fay-chat'),
            'use_featured_image' => __('Use as featured image', 'fay-chat'),
            'insert_into_item' => __('Insert into item', 'fay-chat'),
            'uploaded_to_this_item' => __('Uploaded to this item', 'fay-chat'),
            'items_list' => __('Agents list', 'fay-chat'),
            'items_list_navigation' => __('Agents list navigation', 'fay-chat'),
            'filter_items_list' => __('Filter Agents list', 'fay-chat'),
        );
        $args = array(
            'label' => __('Fay Chat Type', 'fay-chat'),
            'description' => __('Post Type Description', 'fay-chat'),
            'labels' => $labels,
            'supports' => array('title', 'thumbnail'),
            'hierarchical' => false,
            'public' => false,
            'menu_icon' => 'dashicons-format-chat',
            'show_ui' => true,
            'show_in_menu' => true,
            'show_in_admin_bar' => true,
            'show_in_nav_menus' => true,
            'can_export' => true,
            'has_archive' => true,
            'exclude_from_search' => false,
            'publicly_queryable' => true,
            'capability_type' => 'post',
        );
        register_post_type('faychat', $args);
    }
    add_action('init', 'fay_chatcustom_post_type', 0);
}



